@@ -50,9 +50,10 @@ get_connection.SQLiteDriver <- function(
   bigint <- match.arg(bigint)
 
   # Store the given arguments
-  args <- list(...) |>
-    append(as.list(rlang::current_env())) |>
+  args <- as.list(rlang::current_env()) %>%
+    utils::modifyList(list(...)) %>%
     unlist()
+
   args <- args[match(unique(names(args)), names(args))]
 
   # Check arguments
@@ -98,8 +99,8 @@ get_connection.PqDriver <- function(
   bigint <- match.arg(bigint)
 
   # Store the given arguments
-  args <- list(...) |>
-    append(as.list(rlang::current_env())) |>
+  args <- as.list(rlang::current_env()) %>%
+    utils::modifyList(list(...)) %>%
     unlist()
   args <- args[match(unique(names(args)), names(args))]
 
@@ -143,8 +144,8 @@ get_connection.OdbcDriver <- function(
   bigint <- match.arg(bigint)
 
   # Store the given arguments
-  args <- list(...) |>
-    append(as.list(rlang::current_env())) |>
+  args <- as.list(rlang::current_env()) %>%
+    utils::modifyList(list(...)) %>%
     unlist()
   args <- args[match(unique(names(args)), names(args))]
 
@@ -155,6 +156,14 @@ get_connection.OdbcDriver <- function(
   checkmate::assert_choice(timezone_out, OlsonNames(), null.ok = TRUE, add = coll)
   checkmate::reportAssertions(coll)
 
+  # Recommend batch processing for ODBC connections
+  if (is.null(getOption("odbc.batch_rows"))) {
+    message(
+      "Transfer of large data sets may be slow. ",
+      "Consider using options(\"odbc.batch_rows\" = 1000) to speed up transfer."
+    )
+  }
+
   # Check if connection can be established given these settings
   status <- do.call(DBI::dbCanConnect, args = args)
   if (!status) stop(attr(status, "reason"))
@@ -178,8 +187,8 @@ get_connection.duckdb_driver <- function(
   bigint <- match.arg(bigint)
 
   # Store the given arguments
-  args <- list(...) |>
-    append(as.list(rlang::current_env())) |>
+  args <- as.list(rlang::current_env()) %>%
+    utils::modifyList(list(...)) %>%
     unlist()
   args <- args[match(unique(names(args)), names(args))]
 
@@ -200,11 +209,12 @@ get_connection.duckdb_driver <- function(
 
 #' @rdname get_connection
 #' @export
+#' @importFrom magrittr %>%
 get_connection.default <- function(drv, ...) {
 
   # Store the given arguments
-  args <- list(...) |>
-    append(as.list(rlang::current_env())) |>
+  args <- as.list(rlang::current_env()) %>%
+    utils::modifyList(list(...)) %>%
     unlist()
   args <- args[match(unique(names(args)), names(args))]
 
@@ -237,5 +247,5 @@ close_connection <- function(conn) {
   # Check arguments
   checkmate::assert_class(conn, "DBIConnection")
 
-  DBI::dbDisconnect(conn, shutdown = TRUE)
+  DBI::dbDisconnect(conn)
 }
