@@ -1,11 +1,13 @@
 #' Get a list of data base connections to test on
+#' @param skip_backends (`character()`)\cr
+#'   List of connection types to not return connections for.
 #' @return
 #'   If you run your tests locally, it returns a list of connections corresponding to conn_list and conn_args
 #'   If you run your tests on GitHub, it return a list of connection corresponding to the environment variables.
 #'   i.e. the GitHub workflows will configure the testing back ends
 #' @importFrom rlang `:=`
 #' @noRd
-get_test_conns <- function() {
+get_test_conns <- function(skip_backends = NULL) {
 
   # Locally use rlang's (without this, it may not be bound)
   `:=` <- rlang::`:=`
@@ -42,17 +44,17 @@ get_test_conns <- function() {
   } else {
 
     # Use the connection configured by the remote
-    conn_list <- tibble::lst(!!Sys.getenv("BACKEND") := !!Sys.getenv("BACKEND_DRV"))                                    # nolint: object_name_linter
+    conn_list <- tibble::lst(!!Sys.getenv("BACKEND") := !!Sys.getenv("BACKEND_DRV"))
 
     # Use the connection configured by the remote
-    conn_args <- tibble::lst(!!Sys.getenv("BACKEND") := Sys.getenv("BACKEND_ARGS")) |>                                  # nolint: object_name_linter
-      purrr::discard(~ identical(., "")) |>
-      purrr::map(~ eval(parse(text = .)))
+    conn_args <- tibble::lst(!!Sys.getenv("BACKEND") := Sys.getenv("BACKEND_ARGS"))
+    conn_args <- purrr::discard(conn_args, ~ identical(., ""))
+    conn_args <- purrr::map(conn_args, ~ eval(parse(text = .)))
 
     # Use the connection configured by the remote
-    conn_post_connect <- tibble::lst(!!Sys.getenv("BACKEND") := Sys.getenv("BACKEND_POST_CONNECT")) |>                  # nolint: object_name_linter
-      purrr::discard(~ identical(., "")) |>
-      purrr::map(~ eval(parse(text = .)))
+    conn_post_connect <- tibble::lst(!!Sys.getenv("BACKEND") := Sys.getenv("BACKEND_POST_CONNECT"))
+    conn_post_connect <- purrr::discard(conn_post_connect, ~ identical(., ""))
+    conn_post_connect <- purrr::map(conn_post_connect, ~ eval(parse(text = .)))
 
   }
 
@@ -66,9 +68,8 @@ get_test_conns <- function() {
 
   # Combine all arguments
   backends <- unique(c(names(conn_list), names(conn_args), names(conn_args_json)))
-  conn_args <- backends |>
-    purrr::map(~ c(purrr::pluck(conn_args, .), purrr::pluck(conn_args_json, .))) |>
-    stats::setNames(backends)
+  conn_args <- purrr::map(backends, ~ c(purrr::pluck(conn_args, .), purrr::pluck(conn_args_json, .)))
+  names(conn_args) <- backends
 
 
   get_driver <- function(x = character(), ...) {                                                                        # nolint: object_usage_linter
@@ -89,24 +90,43 @@ get_test_conns <- function() {
   checkmate::assert_subset(names(conn_args), names(conn_list))
 
   # Open connections
-  drivers <- names(conn_list) |>
-    purrr::map(~ do.call(get_driver, list(x = purrr::pluck(conn_list, .)))) |>
-    stats::setNames(names(conn_list)) |>
-    purrr::discard(is.null)
+  drivers <- purrr::map(names(conn_list), ~ do.call(get_driver, list(x = purrr::pluck(conn_list, .))))
+  names(drivers) <- names(conn_list)
+  drivers <- purrr::discard(drivers, is.null)
 
-  test_conns <- names(drivers) |>
-    purrr::map(~ do.call(SCDB::get_connection, c(list(drv = purrr::pluck(drivers, .)), purrr::pluck(conn_args, .)))) |>
-    stats::setNames(names(drivers)) |>
-    purrr::discard(is.null)
+  test_conn_args <- purrr::map(
+    names(drivers),
+    ~ c(list("drv" = purrr::pluck(drivers, .)), purrr::pluck(conn_args, .))
+  )
+
+  test_conns <- purrr::map(
+    test_conn_args,
+    ~ do.call(SCDB::get_connection, args = .)
+  )
+  names(test_conns) <- names(drivers)
+  test_conns <- purrr::discard(test_conns, is.null)
+
+  # Skip backends if given
+  test_conns <- purrr::walk(
+    test_conns,
+    ~ {
+      if (checkmate::test_multi_class(., purrr::pluck(skip_backends, .default = ""))) {
+        DBI::dbDisconnect(.)
+      }
+    }
+  )
+  test_conns <- purrr::discard(
+    test_conns,
+    ~ checkmate::test_multi_class(., purrr::pluck(skip_backends, .default = ""))
+  )
 
   # Run post_connect commands on the connections
-  purrr::walk2(test_conns, names(test_conns),
-               \(conn, conn_name) purrr::walk(purrr::pluck(conn_post_connect, conn_name), ~ DBI::dbExecute(conn, .)))
-
-  # Shutdown drivers that needs it
-  drivers |>
-    purrr::keep(~ inherits(., "duckdb_driver")) |>
-    purrr::walk(~ duckdb::duckdb_shutdown(.))
+  purrr::iwalk(
+    test_conns,
+    function(conn, conn_name) {
+      purrr::walk(purrr::pluck(conn_post_connect, conn_name), ~ DBI::dbExecute(conn, .))
+    }
+  )
 
   # Inform the user about the tested back ends:
   msg <- paste(sep = "\n",
@@ -125,3 +145,30 @@ get_test_conns <- function() {
 
   return(test_conns)
 }
+
+
+#' Parse checkmate assertions for testthat compatibility
+#' @description
+#'   The error messages generated by `checkmate` are formatted to look nicely in the console by the
+#'   addition of `*` and `\n` characters.
+#'
+#'   This means that checking these errors with `testthat::expect_error()` will often fail or will be harder to read
+#'   in the test since we need to manually insert `*` and `\n` to the comparison pattern to match the error message.
+#'
+#'   This helper function intercepts the `checkmate` error message and removes the `*` and `\n` characters to allow for
+#'   human readable error checking.
+#' @return
+#'   The checkmate error without `*` and `\n` characters.
+#' @noRd
+checkmate_err_msg <- function(expr) {
+  tryCatch(
+    expr,
+    error = function(e) {
+      msg <- e$message
+      msg <- stringr::str_remove_all(msg, stringr::fixed("\n *"))
+      msg <- stringr::str_remove_all(msg, stringr::fixed("* "))
+
+      stop(simpleError(message = msg))
+    }
+  )
+}
