@@ -20,7 +20,7 @@ for (conn_id in seq_along(conns)) {
     coll$push(glue::glue("Tests require the schema 'test.one' to exist in connection ({names(conns)[[conn_id]]})."))
   }
 
-  DBI::dbDisconnect(conn, shutdown = TRUE)
+  DBI::dbDisconnect(conn)
 }
 checkmate::reportAssertions(coll)
 
@@ -39,21 +39,21 @@ for (conn in get_test_conns()) {
 
 
   # Copy mtcars to conn
-  dplyr::copy_to(conn, mtcars |> dplyr::mutate(name = rownames(mtcars)),
+  dplyr::copy_to(conn, mtcars %>% dplyr::mutate(name = rownames(mtcars)),
                  name = id("test.mtcars", conn), temporary = FALSE, overwrite = TRUE)
 
-  dplyr::copy_to(conn, mtcars |> dplyr::mutate(name = rownames(mtcars)),
+  dplyr::copy_to(conn, mtcars %>% dplyr::mutate(name = rownames(mtcars)),
                  name = id("__mtcars", conn), temporary = FALSE, overwrite = TRUE)
 
   dplyr::copy_to(conn,
-                 mtcars |>
-                   dplyr::mutate(name = rownames(mtcars)) |>
-                   digest_to_checksum() |>
+                 mtcars %>%
+                   dplyr::mutate(name = rownames(mtcars)) %>%
+                   digest_to_checksum() %>%
                    dplyr::mutate(from_ts = as.POSIXct("2020-01-01 09:00:00"),
                                  until_ts = as.POSIXct(NA)),
                  name = id("__mtcars_historical", conn), temporary = FALSE, overwrite = TRUE)
 
-  DBI::dbDisconnect(conn, shutdown = TRUE)
+  DBI::dbDisconnect(conn)
 }
 
 
@@ -68,5 +68,5 @@ connection_clean_up <- function(conn) {
   if (nrow(dplyr::filter(get_tables(conn, show_temporary = TRUE), stringr::str_detect(.data$table, "^#?dbplyr_")))) {
     warning("Temporary dbplyr tables ('dbplyr_###') are not cleaned up!")
   }
-  DBI::dbDisconnect(conn, shutdown = TRUE)
+  DBI::dbDisconnect(conn)
 }
